@@ -32,7 +32,7 @@ QPair<int, QByteArray> AINetWork::request(const QJsonObject &data, const QString
         }
     }
 
-    if (baseresult.error != AIServer::NoError && baseresult.data.isEmpty()) {
+    if ((baseresult.error != AIServer::NoError && baseresult.data.isEmpty()) || baseresult.error == AIServer::ContentExceededError) {
         baseresult.data = ServerCodeTranslation::serverCodeTranslation(baseresult.error, baseresult.errorString).toUtf8();
     }
 
