@@ -11,7 +11,15 @@ OsInfo::OsInfo(QObject *parent)
     : QObject{parent}
 {
     m_pureEnvironment = QProcessEnvironment::systemEnvironment();
+}
 
+QProcessEnvironment OsInfo::pureEnvironment()
+{
+    return m_pureEnvironment;
+}
+
+void OsInfo::printInfo()
+{
     qInfo() << "{"
             << DSysInfo::uosEditionName() << ","
             << DSysInfo::productTypeString() << ","
@@ -22,19 +30,3 @@ OsInfo::OsInfo(QObject *parent)
             << "}";
     qInfo() << "cache system environment" << m_pureEnvironment.toStringList();
 }
-
-bool OsInfo::isLingLong() const
-{
-    //TODO:
-    //   Now only Deepin Community have linglong ISO
-    //UOS don't have linglong edtion,maybe need change
-    //the conditon in future.
-    bool isLingLong = (DSysInfo::ProductType::Deepin == DSysInfo::productType())
-                      && DSysInfo::productVersion() == QString("23");
-    return isLingLong;
-}
-
-QProcessEnvironment OsInfo::pureEnvironment()
-{
-    return m_pureEnvironment;
-}
