@@ -6,7 +6,10 @@
 #define LLMSERVICEVENDOR_H
 
 #include "serverdefs.h"
-#include "externalllm/exteralllmloader.h"
+#include "externalllm/externalllmloader.h"
+#include "externalllm/externalagentloader.h"
+#include "externalllm/externalagent.h"
+#include "externalllm/modelhubllm.h"
 #include "llmplugin.h"
 #include "llm.h"
 
@@ -19,7 +22,7 @@ class LLMServiceVendor : public QObject
     Q_OBJECT
 public:
     explicit LLMServiceVendor(QObject *parent = nullptr);
-    void initModelPlugin();
+    void initExternal();
     LLMServerProxy checkUpdateLLmAccount(const QString &llmId);
     LLMServerProxy queryValidServerAccount(const QString &llmId);
     QList<LLMServerProxy> queryServerAccountByRole(const AssistantProxy &role);
@@ -32,17 +35,26 @@ public:
 
     QList<AssistantProxy> queryAssistantList();
     AssistantProxy queryAssistantById(const QString &assistantId);
+    QString queryIconById(const QString &assistantId, const QString &modelId);
+    QString queryDisplayNameById(const QString &assistantId);
 
     QVariant getFAQ(const QString &assistantId);
-
+protected:
+    void initModelPlugin();
+    void initAgent();
 signals:
-
+    void agentChanged();
 public slots:
+private slots:
+    void updateAgent();
 
 private:
     QMap<QString, LLMServerProxy> extServer;
     QMap<QString, QSharedPointer<LLMPlugin>> extPlugins;
-    uos_ai::ExteralLLMLoader llmLoader;
+    uos_ai::ExternalLLMLoader llmLoader;
+    uos_ai::ExternalAgentLoader agentLoader;
+    ModelHubLLM modelhub;
+
 };
 
 }
